# Quick Start
You can use `Rehearser` to build reliable unit tests quickly

Please check https://github.com/kevinchwong/rehearser-examples

----

## Installation

```bash
pip install rehearser
```

## Tutorials
  - [Introduction](https://medium.com/@kevinchwong/unveiling-rehearser-revolutionize-your-python-unit-tests-d53eaa809d23)
  - [Step-by-step](https://medium.com/@kevinchwong/unlock-the-secrets-of-efficient-python-testing-with-rehearser-2b967f16c706)



